# Spring Project

Welcome to the Spring Project!

## Table of Contents

- [Spring Project](#spring-project)
  - [Table of Contents](#table-of-contents)
  - [Introduction](#introduction)
  - [Installation](#installation)
  - [Documentation](#documentation)
  - [Contributing](#contributing)
  - [License](#license)

## Introduction

This project implements [Stream Monitoring under the Time Warping Distance](https://www.cs.cmu.edu/~christos/PUBLICATIONS/ICDE07-spring.pdf)

## Installation

To install the Spring Project, follow these steps:

```bash
pip install twdspring
```

## Documentation

[https://aastafiev.github.io/twdspring/](https://aastafiev.github.io/twdspring/)

## Contributing

We welcome contributions! Please read our [contributing guidelines](CONTRIBUTING.md) for more information.

## License

This project is licensed under the GNU GPLv3.
